summaryrefslogtreecommitdiffstats
path: root/src/net/infiniband.c
diff options
context:
space:
mode:
authorMichael Brown2009-07-17 23:40:12 +0200
committerMichael Brown2009-07-18 00:06:35 +0200
commitea6eb7f7ed32f6141813b8f0c3e382b1d2bdcbd8 (patch)
treef29fb470495b29fe03e533d15a6b9bbcecdf54a7 /src/net/infiniband.c
parent[infiniband] Expose supported and enabled link speeds and widths (diff)
downloadipxe-ea6eb7f7ed32f6141813b8f0c3e382b1d2bdcbd8.tar.gz
ipxe-ea6eb7f7ed32f6141813b8f0c3e382b1d2bdcbd8.tar.xz
ipxe-ea6eb7f7ed32f6141813b8f0c3e382b1d2bdcbd8.zip
[infiniband] Pass a generic MAD to ib_set_port_info()
Diffstat (limited to 'src/net/infiniband.c')
-rw-r--r--src/net/infiniband.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/net/infiniband.c b/src/net/infiniband.c
index b15dcc61..513e40c9 100644
--- a/src/net/infiniband.c
+++ b/src/net/infiniband.c
@@ -687,13 +687,13 @@ int ib_get_hca_info ( struct ib_device *ibdev,
return num_ports;
}
-/** Set port information
+/**
+ * Set port information
*
* @v ibdev Infiniband device
* @v port_info New port information
*/
-int ib_set_port_info ( struct ib_device *ibdev,
- const struct ib_port_info *port_info ) {
+int ib_set_port_info ( struct ib_device *ibdev, union ib_mad *mad ) {
int rc;
/* Adapters with embedded SMAs do not need to support this method */
@@ -703,7 +703,7 @@ int ib_set_port_info ( struct ib_device *ibdev,
return -ENOTSUP;
}
- if ( ( rc = ibdev->op->set_port_info ( ibdev, port_info ) ) != 0 ) {
+ if ( ( rc = ibdev->op->set_port_info ( ibdev, mad ) ) != 0 ) {
DBGC ( ibdev, "IBDEV %p could not set port information: %s\n",
ibdev, strerror ( rc ) );
return rc;
@@ -687,13 +687,13 @@ int ib_get_hca_info ( struct ib_device *ibdev,
*
* @v ibdev Infiniband device
- * @v port_info New port information
+ * @v mad Set port information MAD
*/